import { __assign } from "tslib";
import React from "react";
import classNames from "classnames";
import { useMedia } from "utils-hooks";
import RowContext from "./RowContext";
export var responsiveArray = ["xxl", "xl", "lg", "md", "sm", "xs"];
var responsiveMap = {
    xs: "(max-width: 575px)",
    sm: "(min-width: 576px)",
    md: "(min-width: 768px)",
    lg: "(min-width: 992px)",
    xl: "(min-width: 1200px)",
    xxl: "(min-width: 1600px)"
};
function getGutter(gutter, currentBreakpoint) {
    if (typeof gutter === "object") {
        for (var i = 0; i < responsiveArray.length; ++i) {
            var breakpoint = responsiveArray[i];
            if (currentBreakpoint === breakpoint && gutter[currentBreakpoint] !== undefined) {
                return gutter[currentBreakpoint];
            }
        }
    }
    else {
        return gutter;
    }
}
export function Row(props) {
    var _a;
    var className = props.className, type = props.type, _b = props.justify, justify = _b === void 0 ? "start" : _b, _c = props.align, align = _c === void 0 ? "top" : _c, children = props.children;
    // 获取当前媒体查询 Breakpoint
    var breakpoint = useMedia(Object.values(responsiveMap), Object.keys(responsiveMap), null);
    var gutter = getGutter(props.gutter, breakpoint);
    var isFlex = type === "flex";
    var prefixCls = isFlex ? "ant-row-flex" : "ant-row";
    var classString = classNames(prefixCls, className, (_a = {},
        _a[prefixCls + "-" + justify] = isFlex && justify,
        _a[prefixCls + "-" + align] = isFlex && align,
        _a));
    var half = gutter / -2;
    var style = gutter > 0 ? __assign(__assign({}, props.style), { marginLeft: half, marginRight: half }) : props.style;
    return (React.createElement(RowContext.Provider, { value: { gutter: gutter } },
        React.createElement("div", { className: classString, style: style }, children)));
}
export default React.memo(Row);
//# sourceMappingURL=Row.js.map